@@ -10,7 +10,7 @@ use List::Util qw(first);
 use Bitcoin::Crypto::Key::Public;
 use Bitcoin::Crypto::Base58 qw(encode_base58check decode_base58check);
 use Bitcoin::Crypto::Config;
-use Bitcoin::Crypto::Network qw(find_network get_network);
+use Bitcoin::Crypto::Network;
 use Bitcoin::Crypto::Util qw(validate_wif);
 use Bitcoin::Crypto::Helpers qw(ensure_length);
 use Bitcoin::Crypto::Exception;
@@ -24,7 +24,7 @@ sub to_wif
 	my ($self) = @_;
 	my $bytes = $self->to_bytes();
 	# wif network - 1B
-	my $wifdata = $self->network->{wif_byte};
+	my $wifdata = $self->network->wif_byte;
 	# key entropy - 32B
 	$wifdata .= ensure_length $bytes, $config{key_max_length};
 	# additional byte for compressed key - 1B
@@ -51,7 +51,7 @@ sub from_wif
 	}
 
 	my $wif_network_byte = substr $decoded, 0, 1;
-	my @found_networks = find_network(wif_byte => $wif_network_byte);
+	my @found_networks = Bitcoin::Crypto::Network->find(sub { shift->wif_byte eq $wif_network_byte });
 	@found_networks = first { $_ eq $network } @found_networks if defined $network;
 
 	Bitcoin::Crypto::Exception::KeyCreate->raise(
@@ -198,7 +198,7 @@ Returns current key instance.
 
 	sig: set_network($self, $val)
 
-Change key's network state to $val. It can be either network name present in Bitcoin::Crypto::Network package or a valid network hashref. This will change the WIF generated by to_wif() method and also enable creation of public keys generating this network's addresses.
+Change key's network state to $val. It can be either network name present in Bitcoin::Crypto::Network package or an instance of this class.
 
 Returns current key instance.
 
