@@ -1,14 +1,10 @@
 package Bitcoin::Crypto::Segwit;
 
-our $VERSION = "0.997_01";
-
-use v5.10;
-use warnings;
+use Modern::Perl "2010";
 use Exporter qw(import);
 
 use Bitcoin::Crypto::Exception;
 use Bitcoin::Crypto::Config;
-use Bitcoin::Crypto::Helpers qw(verify_bytestring);
 
 our @EXPORT_OK = qw(
 	validate_program
@@ -40,21 +36,19 @@ sub common_validator
 sub validate_program
 {
 	my ($program) = @_;
-	verify_bytestring($program);
 
 	my $version = unpack "C", $program;
 	Bitcoin::Crypto::Exception::SegwitProgram->raise(
-		"incorrect witness program version " . ($version // "[null]")
+		"incorrect witness program version $version"
 	) unless defined $version && $version >= 0 && $version <= $config{max_witness_version};
 
 	$program = substr $program, 1;
 	my $validator = $validators{$version};
 	common_validator($program);
-	if (defined $validator && ref $validator eq ref sub { }) {
+	if (defined $validator && ref $validator eq ref sub{}) {
 		$validator->($program);
-	}
-	else {
-		warn("No validator for SegWit program version $version is declared");
+	} else {
+		warn("No validator for segwit program version $version is declared");
 	}
 
 	return $version;
@@ -65,17 +59,14 @@ sub validate_program
 __END__
 =head1 NAME
 
-Bitcoin::Crypto::Segwit - Segregated Witness version definitions
+Bitcoin::Crypto::Segwit
 
 =head1 SYNOPSIS
 
-	use Bitcoin::Crypto::Segwit qw(validate_program);
 
-	my $program_version = validate_program($segwit_program);
 
 =head1 DESCRIPTION
 
-This module provides tools required to define and use a Segregated Witness version validator.
 
 =head1 FUNCTIONS
 
@@ -111,7 +102,7 @@ This module throws an instance of L<Bitcoin::Crypto::Exception> if it encounters
 
 =over 2
 
-=item * SegwitProgram - a validation of a segwit program has failed
+=item SegwitProgram - a validation of a segwit program has failed
 
 =back
 
